@@ -30,18 +30,6 @@ mod handler;
 #[cfg(any(feature = "tokio-stdio", feature = "tokio-tcp"))]
 pub mod listen;
 
-#[cfg(feature = "unsend")]
-pub trait SendBound {}
-
-#[cfg(feature = "unsend")]
-impl<T> SendBound for T {}
-
-#[cfg(not(feature = "unsend"))]
-pub trait SendBound: Send {}
-
-#[cfg(not(feature = "unsend"))]
-impl<T> SendBound for T where T: Send {}
-
 #[derive(Debug, Clone, Default)]
 struct Cancellation {
     cancelled: Arc<AtomicBool>,
@@ -130,21 +118,19 @@ impl FusedFuture for CancelTokenErr<'_> {
     }
 }
 
-#[cfg_attr(feature = "send", async_trait)]
-#[cfg_attr(not(feature = "send"), async_trait(?Send))]
+#[async_trait(?Send)]
 pub trait ResponseWriter: Sized {
-    async fn write_response<R: Serialize + Send + Sync>(
+    async fn write_response<R: Serialize>(
         mut self,
         response: &rpc::Response<R>,
     ) -> Result<(), io::Error>;
 }
 
-#[cfg_attr(feature = "send", async_trait)]
-#[cfg_attr(not(feature = "send"), async_trait(?Send))]
+#[async_trait(?Send)]
 pub trait RequestWriter {
     async fn write_request<
         R: Request<Params = P>,
-        P: Serialize + DeserializeOwned + Send + Sync + core::fmt::Debug,
+        P: Serialize + DeserializeOwned + core::fmt::Debug,
     >(
         &mut self,
         params: Option<R::Params>,
@@ -152,7 +138,7 @@ pub trait RequestWriter {
 
     async fn write_notification<
         N: Notification<Params = P>,
-        P: Serialize + DeserializeOwned + Send + Sync + core::fmt::Debug,
+        P: Serialize + DeserializeOwned + core::fmt::Debug,
     >(
         &mut self,
         params: Option<N::Params>,
@@ -161,13 +147,13 @@ pub trait RequestWriter {
     async fn cancel(&mut self) -> Result<(), io::Error>;
 }
 
-trait NewTrait: Future<Output = ()> + SendBound {}
-impl<T> NewTrait for T where T: Future<Output = ()> + SendBound {}
+trait NewTrait: Future<Output = ()> {}
+impl<T> NewTrait for T where T: Future<Output = ()> {}
 
 type DeferredTasks = Arc<AsyncMutex<Vec<Pin<Box<dyn NewTrait>>>>>;
 
 #[derive(Clone)]
-pub struct Context<W: Clone + Send + Sync> {
+pub struct Context<W: Clone> {
     inner: Arc<AsyncMutex<Inner<W>>>,
     cancel_token: CancelToken,
     last_req_id: Option<rpc::RequestId>, // For cancellation
@@ -176,7 +162,7 @@ pub struct Context<W: Clone + Send + Sync> {
     deferred: DeferredTasks,
 }
 
-impl<W: Clone + Send + Sync> Context<W> {
+impl<W: Clone> Context<W> {
     pub async fn is_initialized(&self) -> bool {
         self.inner.lock().await.initialized
     }
@@ -198,18 +184,17 @@ impl<W: Clone + Send + Sync> Context<W> {
     ///
     /// If sending a response fails, deferred futures
     /// won't be executed.
-    pub async fn defer<F: Future<Output = ()> + SendBound + 'static>(&self, fut: F) {
+    pub async fn defer<F: Future<Output = ()> + 'static>(&self, fut: F) {
         self.deferred.lock().await.push(Box::pin(fut));
     }
 }
 
-#[cfg_attr(feature = "send", async_trait)]
-#[cfg_attr(not(feature = "send"), async_trait(?Send))]
-impl<W: Clone + Send + Sync> RequestWriter for Context<W> {
+#[async_trait(?Send)]
+impl<W: Clone> RequestWriter for Context<W> {
     #[tracing::instrument(level = tracing::Level::TRACE, skip(self))]
     async fn write_request<
         R: Request<Params = P>,
-        P: Serialize + DeserializeOwned + SendBound + core::fmt::Debug,
+        P: Serialize + DeserializeOwned + core::fmt::Debug,
     >(
         &mut self,
         params: Option<R::Params>,
@@ -250,7 +235,7 @@ impl<W: Clone + Send + Sync> RequestWriter for Context<W> {
     #[tracing::instrument(level = tracing::Level::TRACE, skip(self))]
     async fn write_notification<
         N: Notification<Params = P>,
-        P: Serialize + DeserializeOwned + SendBound + core::fmt::Debug,
+        P: Serialize + DeserializeOwned + core::fmt::Debug,
     >(
         &mut self,
         params: Option<N::Params>,
@@ -275,10 +260,10 @@ impl<W: Clone + Send + Sync> RequestWriter for Context<W> {
     }
 }
 
-pub trait MessageWriter: Sink<rpc::Message, Error = io::Error> + SendBound + Unpin {}
-impl<T: Sink<rpc::Message, Error = io::Error> + SendBound + Unpin> MessageWriter for T {}
+pub trait MessageWriter: Sink<rpc::Message, Error = io::Error> + Unpin {}
+impl<T: Sink<rpc::Message, Error = io::Error> + Unpin> MessageWriter for T {}
 
-struct Inner<W: Clone + Send + Sync> {
+struct Inner<W: Clone> {
     next_request_id: i32,
     initialized: bool,
     shutting_down: bool,
@@ -287,7 +272,7 @@ struct Inner<W: Clone + Send + Sync> {
     requests: HashMap<rpc::RequestId, oneshot::Sender<rpc::Response<serde_json::Value>>>,
 }
 
-impl<W: Clone + Send + Sync> Inner<W> {
+impl<W: Clone> Inner<W> {
     fn task_done(&mut self, id: &rpc::RequestId) {
         if let Some(mut t) = self.tasks.remove(id) {
             t.cancel();
@@ -296,11 +281,11 @@ impl<W: Clone + Send + Sync> Inner<W> {
     }
 }
 
-pub struct Server<W: Clone + Send + Sync> {
+pub struct Server<W: Clone> {
     inner: Arc<AsyncMutex<Inner<W>>>,
 }
 
-impl<W: Clone + Send + Sync> Server<W> {
+impl<W: Clone> Server<W> {
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> ServerBuilder<W> {
         ServerBuilder {
@@ -577,16 +562,15 @@ impl<W: Clone + Send + Sync> Server<W> {
     }
 }
 
-pub struct ServerBuilder<W: Clone + Send + Sync + 'static> {
+pub struct ServerBuilder<W: Clone + 'static> {
     inner: Inner<W>,
 }
 
-impl<W: Clone + Send + Sync + 'static> ServerBuilder<W> {
+impl<W: Clone + 'static> ServerBuilder<W> {
     pub fn on_notification<N, F>(mut self, handler: fn(Context<W>, Params<N::Params>) -> F) -> Self
     where
         N: Notification + 'static,
-        N::Params: SendBound,
-        F: Future<Output = ()> + SendBound + 'static,
+        F: Future<Output = ()> + 'static,
     {
         self.inner.handlers.insert(
             N::METHOD.into(),
@@ -599,9 +583,7 @@ impl<W: Clone + Send + Sync + 'static> ServerBuilder<W> {
     pub fn on_request<R, F>(mut self, handler: fn(Context<W>, Params<R::Params>) -> F) -> Self
     where
         R: Request + 'static,
-        R::Params: SendBound,
-        R::Result: SendBound,
-        F: Future<Output = Result<R::Result, rpc::Error>> + SendBound + 'static,
+        F: Future<Output = Result<R::Result, rpc::Error>> + 'static,
     {
         self.inner.handlers.insert(
             R::METHOD.into(),
